==> miro_3.5.1.orig.tar.gz: miro-3.5.1/osx/plat/filenames.py <==
# Miro - an RSS based video player application
# Copyright (C) 2005-2010 Participatory Culture Foundation
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301 USA
#
# In addition, as a special exception, the copyright holders give
# permission to link the code of portions of this program with the OpenSSL
# library.
#
# You must obey the GNU General Public License in all respects for all of
# the code used other than OpenSSL. If you modify file(s) with this
# exception, you may extend this exception to your version of the file(s),
# but you are not obligated to do so. If you do not wish to do so, delete
# this exception statement from your version. If you delete this exception
# statement from all source files in the program, then also delete it here.

from miro.util import returns_binary

FilenameType = str

@returns_binary
def os_filename_to_filename_type(filename):
    """Takes filename given by Python or the PyObjC bridge and turn it
    into a FilenameType
    """
    if isinstance(filename, str):
        return FilenameType(filename)
    return filename.encode('utf-8', 'replace')

def filename_type_to_os_filename(filename):
    """Takes a FilenameType and turn it into something the PyObjC bridge accepts.
    """
    return filename.decode('utf-8')

==> miro_4.0.4.orig.tar.gz: miro-4.0.4/osx/plat/filenames.py <==
# Miro - an RSS based video player application
# Copyright (C) 2005, 2006, 2007, 2008, 2009, 2010, 2011
# Participatory Culture Foundation
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301 USA
#
# In addition, as a special exception, the copyright holders give
# permission to link the code of portions of this program with the OpenSSL
# library.
#
# You must obey the GNU General Public License in all respects for all of
# the code used other than OpenSSL. If you modify file(s) with this
# exception, you may extend this exception to your version of the file(s),
# but you are not obligated to do so. If you do not wish to do so, delete
# this exception statement from your version. If you delete this exception
# statement from all source files in the program, then also delete it here.

from miro.util import returns_binary

PlatformFilenameType = str

@returns_binary
def os_filename_to_filename_type(filename):
    """Takes filename given by Python or the PyObjC bridge and turn it
    into a FilenameType
    """
    if isinstance(filename, str):
        return PlatformFilenameType(filename)
    return filename.encode('utf-8', 'replace')

def filename_type_to_os_filename(filename):
    """Takes a FilenameType and turn it into something the PyObjC bridge accepts.
    """
    return filename.decode('utf-8')
